@@ -11,12 +11,11 @@ from .importance import varimp
 from .shap import ShapExplainer
 from .utils import create_description, df_to_dict
 
-
-BASE_RESULTS_PATH = "results"
+BASE_RESULTS_PATH = os.environ.get("BASE_RESULTS_PATH", "results")
 
 
 def mkdir(endpoint, spec_path=""):
-    folder = os.path.join(BASE_RESULTS_PATH, endpoint.func.__name__, spec_path)
+    folder = os.path.join(BASE_RESULTS_PATH, endpoint.profile_func.__name__, spec_path)
     if not os.path.exists(folder):
         os.makedirs(folder)
     return folder
@@ -25,7 +24,7 @@ def mkdir(endpoint, spec_path=""):
 def create_shapley_schema(endpoint):
     """Create shapley schema for endpoint"""
     x, y = endpoint.get_input_and_output_for_profiling()
-    explainer = ShapExplainer(func=endpoint.func, X=x)
+    explainer = ShapExplainer(func=endpoint.profile_func, X=x)
     folder = mkdir(endpoint=endpoint)
     input_descriptions = [create_description(x[col]) for col in x.columns]
     logging.info("Shapley - Creating schema")
@@ -41,7 +40,7 @@ def create_explainer_schema(endpoint, explainer, input_descriptions):
     # create an example
     x, y = endpoint.get_input_and_output_for_profiling()
     x = x.sample(n=1)
-    pred = endpoint.func(x)
+    pred = endpoint.profile_func(x)
     baseline, explanation = explainer.explain(x)
     example = {
         "inputs": df_to_dict(x),
@@ -57,7 +56,7 @@ def create_explainer_schema(endpoint, explainer, input_descriptions):
 def create_accuracy(endpoint):
     """Create accuracy profile for endpoint"""
     x, y = endpoint.get_input_and_output_for_profiling()
-    func = endpoint.func
+    func = endpoint.profile_func
     kind = endpoint.KIND.value
     folder = mkdir(endpoint=endpoint, spec_path="accuracy")
 
@@ -85,7 +84,7 @@ def create_accuracy(endpoint):
 def create_dependence(endpoint):
     """Create partial dependence graphs for all variables"""
     x, y = endpoint.get_input_and_output_for_profiling()
-    func = endpoint.func
+    func = endpoint.profile_func
     folder = mkdir(endpoint=endpoint, spec_path="anatomy/partialdep")
 
     for var in x.columns:
@@ -102,7 +101,7 @@ def create_dependence(endpoint):
 def create_expectations(endpoint):
     """Create conditional expectations graphs for all variables"""
     x, y = endpoint.get_input_and_output_for_profiling()
-    func = endpoint.func
+    func = endpoint.profile_func
     folder = mkdir(endpoint=endpoint, spec_path="anatomy/condexp")
 
     for var in x.columns:
@@ -112,6 +111,8 @@ def create_expectations(endpoint):
         try:
             chart = condexp(func, x, y, var)
             chart.save(fpath, format="json")
+            print(fpath)
+            print(chart)
         except AttributeError as e:
             logging.warning(f"Could not generate valid chart for {var}: {repr(e)}")
 
@@ -119,7 +120,7 @@ def create_expectations(endpoint):
 def create_importance(endpoint):
     """Create variable importance graphs"""
     x, y = endpoint.get_input_and_output_for_profiling()
-    func = endpoint.func
+    func = endpoint.profile_func
 
     logging.info("Explanations - Calculating variable importance")
     if endpoint.KIND.value == "regression":
@@ -143,7 +144,7 @@ def create_importance(endpoint):
 
 
 def create_summary(endpoint):
-    endpoint_name = endpoint.func.__name__
+    endpoint_name = endpoint.profile_func.__name__
     logging.info(f"Summary - creating endpoint summary for endpoint: {endpoint_name}")
     as_json = {
         "name": endpoint_name,
@@ -155,5 +156,3 @@ def create_summary(endpoint):
     folder = mkdir(endpoint=endpoint)
     with open(os.path.join(folder, "summary.json"), "w") as summary:
         json.dump(as_json, summary)
-
-
