@@ -27,13 +27,11 @@ def condexp(func, X, y, var):
 
 def condexp_num(func, X, y, var, n_cut=10):
     """Conditional expectations plot for numerical variables"""
-    pred = func(X)
-    if isinstance(pred, pd.Series):
-        pred = pred.to_numpy()
 
     non_missing = ~X[var].isna()
     X = X[non_missing]
     y = y[non_missing]
+    pred = func(X).to_numpy()
 
     df = X.assign(pred=pred, y=y)
     if df[var].nunique() > n_cut:
@@ -84,10 +82,7 @@ def flatten_index(df):
 
 def condexp_cat(func, X, y, var, n_max=25):
     """Conditional expectations plot for categorical variables"""
-    pred = func(X)
-    if isinstance(pred, pd.Series):
-        pred = pred.to_numpy()
-
+    pred = func(X).to_numpy()
     df = X.assign(pred=pred, y=y)
 
     df_agg = (
@@ -148,9 +143,7 @@ def condexp_datetime(func, X, y, var, n_max=100):
     non_missing = ~X[var].isna()
     X = X[non_missing]
     y = y[non_missing]
-    pred = func(X)
-    if isinstance(pred, pd.Series):
-        pred = pred.to_numpy()
+    pred = func(X).to_numpy()
 
     df = X.assign(pred=pred, y=y)
 
